@@ -10,8 +10,8 @@
 namespace Zend\Mvc;
 
 use ArrayObject;
+use Zend\EventManager\AbstractListenerAggregate;
 use Zend\EventManager\EventManagerInterface;
-use Zend\EventManager\ListenerAggregateInterface;
 use Zend\Mvc\Exception\InvalidControllerException;
 use Zend\Stdlib\ArrayUtils;
 
@@ -37,13 +37,8 @@ use Zend\Stdlib\ArrayUtils;
  * The return value of dispatching the controller is placed into the result
  * property of the MvcEvent, and returned.
  */
-class DispatchListener implements ListenerAggregateInterface
+class DispatchListener extends AbstractListenerAggregate
 {
-    /**
-     * @var \Zend\Stdlib\CallbackHandler[]
-     */
-    protected $listeners = array();
-
     /**
      * Attach listeners to an event manager
      *
@@ -58,21 +53,6 @@ class DispatchListener implements ListenerAggregateInterface
         }
     }
 
-    /**
-     * Detach listeners from an event manager
-     *
-     * @param  EventManagerInterface $events
-     * @return void
-     */
-    public function detach(EventManagerInterface $events)
-    {
-        foreach ($this->listeners as $index => $listener) {
-            if ($events->detach($listener)) {
-                unset($this->listeners[$index]);
-            }
-        }
-    }
-
     /**
      * Listen to the "dispatch" event
      *
